==> php54-owncloud-8.0.3.tgz: share/owncloud/settings/l10n/zh_CN.js <==
OC.L10N.register(
    "settings",
    {
    "Cron" : "计划任务",
    "Sharing" : "共享",
    "Security" : "安全",
    "Email Server" : "电子邮件服务器",
    "Log" : "日志",
    "Authentication error" : "认证错误",
    "Your full name has been changed." : "您的全名已修改。",
    "Unable to change full name" : "无法修改全名",
    "Files decrypted successfully" : "文件解密成功",
    "Couldn't decrypt your files, please check your owncloud.log or ask your administrator" : "无法解密您的文件，请检查您的 owncloud.log 或询问管理员",
    "Couldn't decrypt your files, check your password and try again" : "无法解密您的文件，请检查密码并重试。",
    "Encryption keys deleted permanently" : "加密密钥已经永久删除",
    "Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" : "无法永久删除您的加密密钥，请检查 owncloud.log 或联系管理员",
    "Couldn't remove app." : "无法删除应用。",
    "Backups restored successfully" : "恢复备份成功",
    "Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" : "无法恢复加密密钥，请检查 owncloud.log 或联系管理员",
    "Language changed" : "语言已修改",
    "Invalid request" : "无效请求",
    "Admins can't remove themself from the admin group" : "管理员不能将自己移出管理组。",
    "Unable to add user to group %s" : "无法把用户增加到组 %s",
    "Unable to remove user from group %s" : "无法从组%s中移除用户",
    "Couldn't update app." : "无法更新 app。",
    "Wrong password" : "错误密码",
    "No user supplied" : "没有满足的用户",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "请提供管理员恢复密码，否则所有用户的数据都将遗失。",
    "Wrong admin recovery password. Please check the password and try again." : "错误的管理员恢复密码。请检查密码并重试。",
    "Back-end doesn't support password change, but the users encryption key was successfully updated." : "后端不支持修改密码，但是用户的加密密码已成功更新。",
    "Unable to change password" : "不能更改密码",
    "Enabled" : "开启",
    "Saved" : "已保存",
    "test email settings" : "测试电子邮件设置",
    "If you received this email, the settings seem to be correct." : "如果您收到了这封邮件，看起来设置没有问题。",
    "Email sent" : "邮件已发送",
    "You need to set your user email before being able to send test emails." : "在发送测试邮件前您需要设置您的用户电子邮件。",
    "Email saved" : "电子邮件已保存",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "你真的希望添加 \"{domain}\" 为信任域？",
    "Add trusted domain" : "添加信任域",
    "Sending..." : "正在发送...",
    "All" : "全部",
    "Please wait...." : "请稍等....",
    "Error while disabling app" : "禁用 app 时出错",
    "Disable" : "禁用",
    "Enable" : "开启",
    "Error while enabling app" : "启用 app 时出错",
    "Updating...." : "正在更新....",
    "Error while updating app" : "更新 app 时出错",
    "Updated" : "已更新",
    "Uninstalling ...." : "卸载中....",
    "Error while uninstalling app" : "卸载应用时发生了一个错误",
    "Uninstall" : "卸载",
    "Select a profile picture" : "选择头像",
    "Very weak password" : "非常弱的密码",
    "Weak password" : "弱密码",
    "So-so password" : "一般强度的密码",
    "Good password" : "较强的密码",
    "Strong password" : "强密码",
    "Valid until {date}" : "有效期至 {date}",
    "Delete" : "删除",
    "Decrypting files... Please wait, this can take some time." : "正在解密文件... 请稍等，可能需要一些时间。",
    "Delete encryption keys permanently." : "永久删除加密密钥。",
    "Restore encryption keys." : "恢复加密密钥。",
    "Groups" : "组",
    "Unable to delete {objName}" : "无法删除 {objName}",
    "Error creating group" : "创建组时出错",
    "A valid group name must be provided" : "请提供一个有效的组名称",
    "deleted {groupName}" : "已删除 {groupName}",
    "undo" : "撤销",
    "never" : "从不",
    "deleted {userName}" : "已删除 {userName}",
    "add group" : "增加组",
    "A valid username must be provided" : "必须提供合法的用户名",
    "Error creating user" : "创建用户出错",
    "A valid password must be provided" : "必须提供合法的密码",
    "__language_name__" : "简体中文",
    "SSL root certificates" : "SSL根证书",
    "Encryption" : "加密",
    "Everything (fatal issues, errors, warnings, info, debug)" : "所有（灾难性问题，错误，警告，信息，调试）",
    "Info, warnings, errors and fatal issues" : "信息，警告，错误和灾难性问题",
    "Warnings, errors and fatal issues" : "警告，错误和灾难性问题",
    "Errors and fatal issues" : "错误和灾难性问题",
    "Fatal issues only" : "仅灾难性问题",
    "None" : "无",
    "Login" : "登录",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN 管理器",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "Security Warning" : "安全警告",
    "You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." : "您正通过 HTTP 访问 %s。我们强烈建议您配置你的服务器来要求使用 HTTPS。",
    "Setup Warning" : "设置警告",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 被设置为移除行内 <doc> 块，这将导致数个核心应用无法访问。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能是由缓存/加速器造成的，例如 Zend OPcache 或 eAccelerator。",
    "Database Performance Info" : "数据库性能信息",
    "Module 'fileinfo' missing" : "模块'文件信息'丢失",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP模块'文件信息'丢失. 我们强烈建议启用此模块以便mime类型检测取得最佳结果.",
    "PHP charset is not set to UTF-8" : "PHP字符集没有设置为UTF-8",
    "PHP charset is not set to UTF-8. This can cause major issues with non-ASCII characters in file names. We highly recommend to change the value of 'default_charset' php.ini to 'UTF-8'." : "PHP字符集没有设置为UTF-8。这会导致非ASC||字符的文件名出现乱码。我们强烈建议修改php.ini文件中的'default_charset' 的值为 'UTF-8'",
    "Locale not working" : "本地化无法工作",
    "System locale can not be set to a one which supports UTF-8." : "系统语系无法设置为支持 UTF-8 的语系。",
    "This means that there might be problems with certain characters in file names." : "这意味着一些文件名中的特定字符可能有问题。",
    "URL generation in notification emails" : "在通知邮件里生成URL",
    "No problems found" : "未发现问题",
    "Please double check the <a href='%s'>installation guides</a>." : "请认真检查<a href='%s'>安装指南</a>.",
    "Last cron was executed at %s." : "上次定时任务执行于 %s。",
    "Last cron was executed at %s. This is more than an hour ago, something seems wrong." : "上次定时任务执行于 %s。这是在一个小时之前执行的，可能出了什么问题。",
    "Cron was not executed yet!" : "定时任务还未被执行！",
    "Execute one task with each page loaded" : "每个页面加载后执行一个任务",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php 已注册于一个 webcron 服务来通过 http 每 15 分钟执行 cron.php。",
    "Use system's cron service to call the cron.php file every 15 minutes." : "使用系统 CRON 服务每 15 分钟执行一次 cron.php 文件。",
    "Allow apps to use the Share API" : "允许应用软件使用共享API",
    "Allow users to share via link" : "允许用户通过链接分享文件",
    "Enforce password protection" : "强制密码保护",
    "Allow public uploads" : "允许公开上传",
    "Allow users to send mail notification for shared files" : "允许用户发送共享文件的邮件通知",
    "Set default expiration date" : "设置默认过期日期",
    "Expire after " : "过期于",
    "days" : "天",
    "Enforce expiration date" : "强制过期日期",
    "Allow resharing" : "允许再次共享",
    "Restrict users to only share with users in their groups" : "限制仅与组内用户分享",
    "Exclude groups from sharing" : "在分享中排除组",
    "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取分享，但无法向他人分享。",
    "Enforce HTTPS" : "强制使用 HTTPS",
    "Forces the clients to connect to %s via an encrypted connection." : "强制客户端通过加密连接连接到%s。",
    "Please connect to your %s via HTTPS to enable or disable the SSL enforcement." : "请经由HTTPS连接到这个%s 实例来启用或禁用强制SSL.",
    "This is used for sending out notifications." : "这被用于发送通知。",
    "Send mode" : "发送模式",
    "From address" : "来自地址",
    "mail" : "邮件",
    "Authentication method" : "认证方法",
    "Authentication required" : "需要认证",
    "Server address" : "服务器地址",
    "Port" : "端口",
    "Credentials" : "凭证",
    "SMTP Username" : "SMTP 用户名",
    "SMTP Password" : "SMTP 密码",
    "Test email settings" : "测试电子邮件设置",
    "Send email" : "发送邮件",
    "Log level" : "日志级别",
    "More" : "更多",
    "Less" : "更少",
    "Version" : "版本",
    "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." : "由<a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud社区</a>开发，  <a href=\"https://github.com/owncloud\" target=\"_blank\">源代码</a>在<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>许可证下发布。",
    "More apps" : "更多应用",
    "by" : "被",
    "Documentation:" : "文档：",
    "User Documentation" : "用户文档",
    "Admin Documentation" : "管理员文档",
    "Enable only for specific groups" : "仅对特定的组开放",
    "Uninstall App" : "下载应用",
    "Cheers!" : "干杯！",
    "Administrator Documentation" : "管理员文档",
    "Online Documentation" : "在线文档",
    "Forum" : "论坛",
    "Bugtracker" : "问题跟踪器",
    "Commercial Support" : "商业支持",
    "Get the apps to sync your files" : "安装应用进行文件同步",
    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\">spread the word</a>!" : "<a href=\"https://owncloud.org/contribute\"\n\ttarget=\"_blank\">加入开发</a>\n或\n<a href=\"https://owncloud.org/promote\"\n\ttarget=\"_blank\">帮助推广</a>以支持本项目！",
    "Show First Run Wizard again" : "再次显示首次运行向导",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "你已使用 <strong>%s</strong>，有效空间 <strong>%s</strong>",
    "Password" : "密码",
    "Your password was changed" : "密码已修改",
    "Unable to change your password" : "无法修改密码",
    "Current password" : "当前密码",
    "New password" : "新密码",
    "Change password" : "修改密码",
    "Full Name" : "全名",
    "Email" : "电子邮件",
    "Your email address" : "您的电子邮件",
    "Fill in an email address to enable password recovery and receive notifications" : "填入电子邮件地址从而启用密码恢复和接收通知",
    "Profile picture" : "联系人图片",
    "Upload new" : "上传新的",
    "Select new from Files" : "从文件中选择一个新的",
    "Remove image" : "移除图片",
    "Either png or jpg. Ideally square but you will be able to crop it." : "png 或 jpg。正方形比较理想但你也可以之后对其进行裁剪。",
    "Your avatar is provided by your original account." : "您的头像由您的原始账户所提供。",
    "Cancel" : "取消",
    "Choose as profile image" : "用作头像",
    "Language" : "语言",
    "Help translate" : "帮助翻译",
    "Common Name" : "通用名称",
    "Valid until" : "有效期至",
    "Issued By" : "授权由",
    "Valid until %s" : "有效期至 %s",
    "Import Root Certificate" : "导入根证书",
    "The encryption app is no longer enabled, please decrypt all your files" : "加密 app 不再被启用，请解密您所有的文件",
    "Log-in password" : "登录密码",
    "Decrypt all Files" : "解密所有文件",
    "Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." : "您的加密密钥已经移动到一个备份位置。如果发生了错误您可以恢复密钥，当确认所有文件已经正确解密时才可永久删除密钥。",
    "Restore Encryption Keys" : "恢复加密密钥",
    "Delete Encryption Keys" : "删除加密密钥",
    "Show storage location" : "显示存储位置",
    "Show last log in" : "显示最后登录",
    "Username" : "用户名",
    "Create" : "创建",
    "Admin Recovery Password" : "管理恢复密码",
    "Enter the recovery password in order to recover the users files during password change" : "输入恢复密码来在更改密码的时候恢复用户文件",
    "Add Group" : "增加组",
    "Group" : "分组",
    "Everyone" : "所有人",
    "Admins" : "管理员",
    "Default Quota" : "默认配额",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "请输入存储限额 (ex: \"512 MB\" or \"12 GB\")",
    "Unlimited" : "无限",
    "Other" : "其它",
    "Quota" : "配额",
    "Storage Location" : "存储空间位置",
    "Last Login" : "最后登录",
    "change full name" : "更改全名",
    "set new password" : "设置新密码",
    "Default" : "默认"
},
"nplurals=1; plural=0;");

==> php54-owncloud-8.1.0.tgz: share/owncloud/settings/l10n/zh_CN.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "共享",
    "External Storage" : "外部存储",
    "Cron" : "计划任务",
    "Log" : "日志",
    "Updates" : "更新",
    "Authentication error" : "认证错误",
    "Your full name has been changed." : "您的全名已修改。",
    "Unable to change full name" : "无法修改全名",
    "Couldn't remove app." : "无法删除应用。",
    "Language changed" : "语言已修改",
    "Invalid request" : "无效请求",
    "Admins can't remove themself from the admin group" : "管理员不能将自己移出管理组。",
    "Unable to add user to group %s" : "无法把用户增加到组 %s",
    "Unable to remove user from group %s" : "无法从组%s中移除用户",
    "Couldn't update app." : "无法更新 app。",
    "Wrong password" : "错误密码",
    "No user supplied" : "没有满足的用户",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "请提供管理员恢复密码，否则所有用户的数据都将遗失。",
    "Wrong admin recovery password. Please check the password and try again." : "错误的管理员恢复密码。请检查密码并重试。",
    "Unable to change password" : "不能更改密码",
    "Enabled" : "开启",
    "Saved" : "已保存",
    "test email settings" : "测试电子邮件设置",
    "Email sent" : "邮件已发送",
    "You need to set your user email before being able to send test emails." : "在发送测试邮件前您需要设置您的用户电子邮件。",
    "Email saved" : "电子邮件已保存",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "你真的希望添加 \"{domain}\" 为信任域？",
    "Add trusted domain" : "添加信任域",
    "Sending..." : "正在发送...",
    "All" : "全部",
    "Please wait...." : "请稍等....",
    "Error while disabling app" : "禁用 app 时出错",
    "Disable" : "禁用",
    "Enable" : "开启",
    "Error while enabling app" : "启用 app 时出错",
    "Updating...." : "正在更新....",
    "Error while updating app" : "更新 app 时出错",
    "Updated" : "已更新",
    "Uninstalling ...." : "卸载中....",
    "Error while uninstalling app" : "卸载应用时发生了一个错误",
    "Uninstall" : "卸载",
    "Select a profile picture" : "选择头像",
    "Very weak password" : "非常弱的密码",
    "Weak password" : "弱密码",
    "So-so password" : "一般强度的密码",
    "Good password" : "较强的密码",
    "Strong password" : "强密码",
    "Valid until {date}" : "有效期至 {date}",
    "Delete" : "删除",
    "Groups" : "组",
    "Unable to delete {objName}" : "无法删除 {objName}",
    "Error creating group" : "创建组时出错",
    "A valid group name must be provided" : "请提供一个有效的组名称",
    "deleted {groupName}" : "已删除 {groupName}",
    "undo" : "撤销",
    "never" : "从不",
    "deleted {userName}" : "已删除 {userName}",
    "add group" : "增加组",
    "A valid username must be provided" : "必须提供合法的用户名",
    "Error creating user" : "创建用户出错",
    "A valid password must be provided" : "必须提供合法的密码",
    "__language_name__" : "简体中文",
    "SSL root certificates" : "SSL根证书",
    "Everything (fatal issues, errors, warnings, info, debug)" : "所有（灾难性问题，错误，警告，信息，调试）",
    "Info, warnings, errors and fatal issues" : "信息，警告，错误和灾难性问题",
    "Warnings, errors and fatal issues" : "警告，错误和灾难性问题",
    "Errors and fatal issues" : "错误和灾难性问题",
    "Fatal issues only" : "仅灾难性问题",
    "None" : "无",
    "Login" : "登录",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN 管理器",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 被设置为移除行内 <doc> 块，这将导致数个核心应用无法访问。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能是由缓存/加速器造成的，例如 Zend OPcache 或 eAccelerator。",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP模块'文件信息'丢失. 我们强烈建议启用此模块以便mime类型检测取得最佳结果.",
    "System locale can not be set to a one which supports UTF-8." : "系统语系无法设置为支持 UTF-8 的语系。",
    "This means that there might be problems with certain characters in file names." : "这意味着一些文件名中的特定字符可能有问题。",
    "Allow apps to use the Share API" : "允许应用软件使用共享API",
    "Allow users to share via link" : "允许用户通过链接分享文件",
    "Enforce password protection" : "强制密码保护",
    "Allow public uploads" : "允许公开上传",
    "Allow users to send mail notification for shared files" : "允许用户发送共享文件的邮件通知",
    "Set default expiration date" : "设置默认过期日期",
    "Expire after " : "过期于",
    "days" : "天",
    "Enforce expiration date" : "强制过期日期",
    "Allow resharing" : "允许再次共享",
    "Restrict users to only share with users in their groups" : "限制仅与组内用户分享",
    "Exclude groups from sharing" : "在分享中排除组",
    "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取分享，但无法向他人分享。",
    "Cron was not executed yet!" : "定时任务还未被执行！",
    "Execute one task with each page loaded" : "每个页面加载后执行一个任务",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php 已注册于一个 webcron 服务来通过 http 每 15 分钟执行 cron.php。",
    "Use system's cron service to call the cron.php file every 15 minutes." : "使用系统 CRON 服务每 15 分钟执行一次 cron.php 文件。",
    "This is used for sending out notifications." : "这被用于发送通知。",
    "Send mode" : "发送模式",
    "Encryption" : "加密",
    "From address" : "来自地址",
    "mail" : "邮件",
    "Authentication method" : "认证方法",
    "Authentication required" : "需要认证",
    "Server address" : "服务器地址",
    "Port" : "端口",
    "Credentials" : "凭证",
    "SMTP Username" : "SMTP 用户名",
    "SMTP Password" : "SMTP 密码",
    "Test email settings" : "测试电子邮件设置",
    "Send email" : "发送邮件",
    "Log level" : "日志级别",
    "More" : "更多",
    "Less" : "更少",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特别当使用桌面客户端来同步文件时，不鼓励使用 SQLite 。",
    "Version" : "版本",
    "by" : "被",
    "Documentation:" : "文档：",
    "User Documentation" : "用户文档",
    "Admin Documentation" : "管理员文档",
    "Enable only for specific groups" : "仅对特定的组开放",
    "Uninstall App" : "卸载应用",
    "Cheers!" : "干杯！",
    "Forum" : "论坛",
    "Get the apps to sync your files" : "安装应用进行文件同步",
    "Show First Run Wizard again" : "再次显示首次运行向导",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "你已使用 <strong>%s</strong>，有效空间 <strong>%s</strong>",
    "Password" : "密码",
    "Unable to change your password" : "无法修改密码",
    "Current password" : "当前密码",
    "New password" : "新密码",
    "Change password" : "修改密码",
    "Email" : "电子邮件",
    "Your email address" : "您的电子邮件",
    "Fill in an email address to enable password recovery and receive notifications" : "填入电子邮件地址从而启用密码恢复和接收通知",
    "Profile picture" : "联系人图片",
    "Upload new" : "上传新的",
    "Select new from Files" : "从文件中选择一个新的",
    "Remove image" : "移除图片",
    "Either png or jpg. Ideally square but you will be able to crop it." : "png 或 jpg。正方形比较理想但你也可以之后对其进行裁剪。",
    "Your avatar is provided by your original account." : "您的头像由您的原始账户所提供。",
    "Cancel" : "取消",
    "Choose as profile image" : "用作头像",
    "Language" : "语言",
    "Help translate" : "帮助翻译",
    "Common Name" : "通用名称",
    "Valid until" : "有效期至",
    "Issued By" : "授权由",
    "Valid until %s" : "有效期至 %s",
    "Show storage location" : "显示存储位置",
    "Show last log in" : "显示最后登录",
    "Username" : "用户名",
    "Create" : "创建",
    "Admin Recovery Password" : "管理恢复密码",
    "Enter the recovery password in order to recover the users files during password change" : "输入恢复密码来在更改密码的时候恢复用户文件",
    "Add Group" : "增加组",
    "Group" : "分组",
    "Everyone" : "所有人",
    "Admins" : "管理员",
    "Default Quota" : "默认配额",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "请输入存储限额 (ex: \"512 MB\" or \"12 GB\")",
    "Unlimited" : "无限",
    "Other" : "其它",
    "Full Name" : "全名",
    "Quota" : "配额",
    "Storage Location" : "存储空间位置",
    "Last Login" : "最后登录",
    "change full name" : "更改全名",
    "set new password" : "设置新密码",
    "Default" : "默认"
},
"nplurals=1; plural=0;");
